<?php

require_once INCLUDE_PATH.'Teamnet/Fax/Quickstart/Endpoint.php';
require_once INCLUDE_PATH.'Teamnet/Fax/Quickstart/EndpointGroup.php';

class Teamnet_Fax_Quickstart_Diagnostics {

	private $connectable;
	private $fullyConnectable;
	private $sufficientPhpVersion;
	private $soapAvailable;
	private $definitionsFile;
	private $selectedEndpointGroupId;
	private $testTime;
	private $endpointGroupMap;
	
	public function __construct( $config ) {
		$this->definitionsFile = $config['ServiceExamples']['Definitions'];
		$this->endpointGroupMap = self::createEndpointGroupMap( $config['ServiceHosts'] );
		$this->selectedEndpointGroupId = $config['ServiceExamples']['DefaultEndpointHost'];
	}	
	
	/**
	 * @return the $testDate
	 */
	public function getTestTime() {
		return $this->testTime;
	}

	/**
	 * @return the $definitionsFile
	 */
	public function getDefinitionsFile() {
		return $this->definitionsFile;
	}

	public function isConnectable() {
		return $this->connectable;
	}
	
	public function isFullyConnectable() {
		return $this->fullyConnectable;
	}
	
	public function isSufficientPhpVersion() {
		return $this->sufficientPhpVersion;
	}
	
	public function isDefinitionsWritable() {
		return $this->isWritePermitted( $this->getDefinitionsFile() );
	}	

	public function isConfigurationWritable() {
		return $this->isWritePermitted( Teamnet_Fax_Quickstart_Model::FILE_CONFIG );
	}	

	public function isWritePermitted( $path ) {
		if ( file_exists( $path ) ) {
			$writePermitted = is_writable( $path );
		}
		else {
			$writePermitted = is_writeable( dirname( $path ) );
		}
		return $writePermitted;
	}

	public function isSoapAvailable() {
		return $this->soapAvailable;
	}
	
	public function setSelectedEndpointGroupId( $endpointGroupId ) {
		$this->qsService = null;
		$this->QsVersionInfo = null;
		$this->selectedEndpointGroupId = $endpointGroupId;
	}
	
	public function getSelectedEndpointGroupId() {
		return $this->selectedEndpointGroupId;
	}

	/**
	 * Enter description here ...
	 * @param endpointHostMap
	 */
	private static function createEndpointGroupMap( $endpointHostMap ) {
		$endpointGroupMap = array();
		foreach( $endpointHostMap as $endpointId => $endpointHost ) {
			$endpointGroupMap[$endpointId] = new Teamnet_Fax_Quickstart_EndpointGroup( new Teamnet_Net_Url( $endpointHost ) );
		}
		return $endpointGroupMap;
	}
	
	/* === TEST CASES === */

	public function testPrerequisites() {
		$this->testTime = time();
		// PHP-Version
		$this->sufficientPhpVersion = version_compare( PHP_VERSION, PHP_VERSION_MIN, '>=' );
		// SOAP Unterstützung
		$this->soapAvailable = $this->testSoap();
		$this->testConnectivity();
	}

	public function testSoap() {
		return class_exists( 'SoapClient' );
	}
	
	/**
	 * Enter description here ...
	 */
	private function testConnectivity() {
		// Verbindungstests
		$this->connectable = false;
		$this->fullyConnectable = true;
		foreach( $this->endpointGroupMap as $endpointId => $endpointGroup ) {
			$endpointGroup->testConnectivity( $this->soapAvailable );
			$this->fullyConnectable = $this->fullyConnectable && $endpointGroup->isConnectable();
			$this->connectable = $this->connectable || $endpointGroup->isConnectable();
		}
	}

	public function getEndpointGroupIds() {
		return array_keys( $this->endpointGroupMap );
	}
	
	public function getEndpointGroup( $endpointGroupId ) {
		if ( !array_key_exists( $endpointGroupId, $this->endpointGroupMap ) ) {
			throw new ErrorException( 'Unknown endpoint group \'' . $endpointGroupId . '\'.' );
		}
		return $this->endpointGroupMap[$endpointGroupId];
	}
	
	public function findEndpointGroupId( $url ) {
		$url = new Teamnet_Net_Url( $url );
		$url->setQuery( '' );
		$url->setFragment( '' );
		$url->setPath( '' );
		$urlString = (string) $url;
		$groupId = null;
		foreach( $this->endpointGroupMap as $endpointGroupId => $endpointGroup ) {
			if ( $endpointGroup->getHost() == $urlString ) {
				$groupId = $endpointGroupId;
				break;
			}
		} 
		return $groupId;
	}

	public function report() {
		$report = "=== Testergebnisse ===\n";
		$report .= 'Serversoftware: '.$_SERVER['SERVER_SOFTWARE']."\n";
		$report .= 'Betriebssystem: '.php_uname('s')."\n";
		$report .= 'Architektur: '.php_uname('m')."\n";
		$report .= 'PHP Version: '.PHP_VERSION."\n";
		$report .= 'SOAP Klasse: '.( $this->isSoapAvailable() ? 'vorhanden' : 'NICHT VORHANDEN')."\n";
		$report .= 'Schreibrechte Definitionen (' . $this->getDefinitionsFile() . '): '.( $this->isDefinitionsWritable() ? 'Ok' : 'Nein')."\n";
		$report .= 'Schreibrechte Konfiguration (' . Teamnet_Fax_Quickstart_Model::FILE_CONFIG . '): '.( $this->isConfigurationWritable() ? 'Ok' : 'Nein')."\n\n";
		$report .= '== Endpunkte =='."\n";
		foreach( $this->endpointGroupMap as $endpointGroupId => $endpointGroup ) {
			$status = $endpointGroup->isConnectable() ? 'Ok' : ( $endpointGroup->isConnectableIp() ? 'Nur IP' : 'Fehler' );
			$report .= 'Gruppe \'' . $endpointGroupId . '\' [' . $endpointGroup->getHost() . ']: ' . $status . "\n"; 
		}
		$report .= "\n";
		$report .= '=== SERVER ==='."\n";
		foreach ( $_SERVER as $key => $value ) {
				$report .= $key . ': ' . ( is_array( $value ) ? print_r( $value, true ) : $value ) . "\n";
		}
		return $report;
	}
	
}
