<?php

require_once INCLUDE_PATH.'Teamnet/Net/Url.php';
require_once INCLUDE_PATH.'Teamnet/Fax/Quickstart/Endpoint.php';

class Teamnet_Fax_Quickstart_EndpointGroup {
	
	private $host;
	private $endpointMap;
	private $connectable;
	private $connectableIp;
	
	public function __construct( $endpointHost ) {
		$this->host = $endpointHost;
		$this->endpointMap = self::createEndpointMap( $endpointHost );
		$this->connectable = false;
		$this->connectableIp = false;
	}
	
	private static function createEndpointMap( $endpointHost ) {
		$endpointMap = array( 'Job' => new Teamnet_Fax_Quickstart_Endpoint( $endpointHost->path( '/2.0/job.php' ) ),
		                      'SendFax' => new Teamnet_Fax_Quickstart_Endpoint( $endpointHost->path( '/2.0/sendfax.php' ) ),
		                      'Quickstart' => new Teamnet_Fax_Quickstart_Endpoint( $endpointHost->path( '/2.0/quickstart.php' ) ) );
				return $endpointMap;
	}
	
	public function testConnectivity( $soap = true ) {
		$this->connectableIp = $this->testConnectivityIp();
		$this->connectable = true;
		$endpointMap = $this->getEndpointMap();
		foreach( $endpointMap as $type => $endpoint ) {
			$endpoint->testConnectivity( $soap );
			$this->connectable = $this->connectable && $endpoint->isConnectable(); 
		}
	}
	
	public function isConnectable() {
		return $this->connectable;
	}

	public function isConnectableIp() {
		return $this->connectableIp;
	}

	/**
	 * @return string $endpointHost
	 */
	public function getHost() {
		return $this->host;
	}
	
	protected function testConnectivityIp() {
		$url = $this->getHost();
		$socket = @fsockopen( $url->getHost(), $url->getPort() );

		if ( ! $socket ) {
			return false;
		}
		else {
			fclose( $socket );
			return true;
		}
	}
	
	public function getEndpoint( $endpointId ) {
		if ( !array_key_exists( $endpointId, $this->endpointMap ) ) {
			throw new ErrorException( 'Unknown endpoint  \'' . $endpointId . '\'.' );
		}
		return $this->endpointMap[$endpointId];
	}

	public function getEndpointIds() {
		return array_keys( $this->endpointMap );
	}
	
	/**
	 * @return array $endpointMap
	 */
	public function getEndpointMap() {
		return $this->endpointMap;
	}
	
}
