<?php
/**
 * Fax-API QuickStart
 * Teamnet GmbH (http://www.teamnet.de)
 */

require_once INCLUDE_PATH.'Teamnet/Fax/Soap/Client/Quickstart.php';
require_once INCLUDE_PATH.'Teamnet/Fax/Quickstart/Diagnostics.php';

class Result {

	private $color;
	private $icon;
	private $tooltip;
	
	public static $Ok;
	public static $Warn;
	public static $Fail;
	public static $NA;
	
	public static function init() {
		self::$Ok = new Result( 'green', 'ok', 'Ok' );
		self::$Warn = new Result( 'orange', 'warn', 'Warnung'  );
		self::$Fail = new Result( 'red', 'fail', 'Test nicht bestanden' );
		self::$NA = new Result( '#999999', 'minus', 'Test übersprungen' );
	}
	
	public function __construct( $color, $icon, $tooltip ) {
		$this->color = $color;
		$this->icon = $icon;
		$this->tooltip = $tooltip;
	}
	
	/**
	 * @param string $title
	 * @param bool|int|null $success
	 * @param string $message
	 */
	public function fragment( $test, $title, $result )	{
		$fragment = '<tr><td id="'. $test . '.title" class="testcase">'.$title.'</td>'.
			'<td id="'. $test . '.result"><span style="color:'.$this->color.';">'.$result.'</span></td>'.
			'<td class="resulticon">'.
			'<img src="images/icn_'.$this->icon.'.gif" alt="" title="'.$this->tooltip.'" />'.
			'</td>'.
			"</tr>\n";
		return $fragment;
	}
	
}
Result::init();

class Teamnet_Fax_Quickstart_ViewController {

	private $aExamples;
	private $action;
	private $aHints;
	private $endpointHostNames;
	private $model;
	
	/**
	 * @return the $quickstart
	 */
	public function getModel() {
		return $this->model;
	}

	public function __construct( $model ) {
		$config = &$model->getConfiguration();
		$examplesPath = $config['ServiceExamples']['ExamplesPath']; 

		$this->model = $model;
		$this->aExamples = array( 'sendfax' => self::createSendFaxExampleMap( $examplesPath ), 
		                          'job' => self::createJobExampleMap( $examplesPath ) );
		$this->endpointHostNames = array( 'Productive' => 'Produktiv-System', 'ProductiveSSL' => 'Produktiv-System (SSL)', 'Sandbox' => 'Sandbox-System' );
		$this->aHints = array();
	}
	
	private static function createSendFaxExampleMap( $examplesPath ) {
		return array(
				'desc' 		=> 'Faxe versenden',
				'help_class'=> 'Teamnet_Fax_Soap_Client_SendFax',
				'examples'	=> array(
					'sendpdf' => array(
						'title'			=> 'PDF als Fax versenden',
						'desc'			=> 'Ein PDF Dokument als Fax an eine Zielfaxnummer versenden.',
						'documentTitle' => 'QuickStart PDF-Dokument',
						'script'		=>	$examplesPath.'/sendfax/sendPDFToFaxnumber.php',
						'help_anchor'	=> 'sendFaxToFaxnumber'
					),
					'sendhtml' => array(
						'title'			=> 'HTML als Fax versenden',
						'desc'			=> 'Ein HTML Dokument als Fax an eine Zielfaxnummer versenden.',
						'documentTitle' => 'QuickStart HTML-Dokument',
					    'script'		=>	$examplesPath.'/sendfax/sendHTMLToFaxnumber.php',
						'help_anchor'	=> 'sendFaxToFaxnumber'
					),
					'sendimage' => array(
						'title'			=> 'Bild als Fax versenden',
						'desc'			=> 'Eine Bilddatei im PNG Format als Fax an eine Zielfaxnummer versenden.',
						'documentTitle' => 'QuickStart Bilddokument',
						'script'		=>	$examplesPath.'/sendfax/sendImageToFaxnumber.php',
						'help_anchor'	=> 'sendFaxToFaxnumber'
					),
					'sendplaintext' => array(
						'title'			=> 'Klartext als Fax versenden',
						'desc'			=> 'Einfachen Klartext aus einem Formular als Fax an eine Zielfaxnummer versenden.',
						'documentTitle' => 'QuickStart Textdokument',
						'script'		=>	$examplesPath.'/sendfax/sendPlainTextToFaxnumber.php',
						'help_anchor'	=> 'sendFaxToFaxnumber'
					),
					'sendpdftolist' => array(
						'title'			=> 'PDF an Empfängerliste versenden',
						'desc'			=> 'Ein PDF Dokument an eine Liste von Empfängern versenden',
						'documentTitle' => 'QuickStart PDF-Dokument an Empfängerliste',
						'script'		=>	$examplesPath.'/sendfax/sendPDFToRecipientList.php',
						'help_anchor'	=> 'sendFaxToRecipientList'
					)
				)
			);
	}
	
	private static function createJobExampleMap( $examplesPath ) {
		return array(
			'desc' => 'Abfragen von Job-Informationen',
			'help_class'=> 'Teamnet_Fax_Soap_Client_Job',
			'examples' => array(
				'getjoblist' => array(
					'title'			=> 'Jobs suchen',
					'desc'			=> 'Versandstatus von Jobs ermitteln, welche nach bestimmten '.
									   'Kriterien (Datum, Status etc.) gefiltert werden.',
					'desc2'			=> 'Dieses Beispiel demonstriert den getList API-Aufruf, mit '.
			 						   'denen Sie Jobs anhand verschiedener Kriterien suchen können',
					'script'		=>	$examplesPath.'/job/getList.php',
					'help_anchor'	=> 'getList'
				),
				'getjob' => array(
					'title'			=> 'Status abfragen',
					'desc'			=> 'Den Versandstatus eines Jobs ermitteln.',
					'script'		=>	$examplesPath.'/job/getJob.php',
					'help_anchor'	=> 'getJob'
				),
				'getjobprofile' => array(
					'title'			=> 'Jobprofil abfragen',
					'desc'			=> 'Detailinfos eines Jobs ermitteln.',
					'script'		=>	$examplesPath.'/job/getJobProfile.php',
					'help_anchor'	=> 'getJobProfile'
				),
				'getjobmembers' => array(
					'title'			=> 'Empfänger abfragen',
					'desc'			=> 'Die Empfänger eines Jobs ermitteln.',
					'script'		=> 	$examplesPath.'/job/getJobMembers.php',
					'help_anchor'	=> 'getJobMembers'
				),
				'getmembers' => array(
					'title'			=> 'Empfänger suchen',
					'desc'			=> 'Fax-Empfänger von Jobs ermitteln, welche nach bestimmten '.
									   'Kriterien (Datum, Status etc.) gefiltert werden können.',
					'desc2'			=> 'Dieses Beispiel demonstriert den getMembers API-Aufruf, mit '.
			 						   'denen Sie Fax-Empfänger anhand verschiedener Kriterien suchen können',
					'script'		=> 	$examplesPath.'/job/getMembers.php',
					'help_anchor'	=> 'getMembers'
				),
				'getjobcosts' => array(
					'title'			=> 'Kosten abfragen',
					'desc'			=> 'Die Kosten eines Jobs ermitteln.',
					'script'		=>	$examplesPath.'/job/getJobCosts.php',
					'help_anchor'	=> 'getJobCosts'
				),
				'gettransportstatus' => array(
					'title'			=> 'Transportstatus abfragen',
					'desc'			=> 'Den momentanten Transportstatus eines FaxJobs ermitteln.',
					'script'		=> $examplesPath.'/job/getTransportStatus.php',
					'help_anchor'	=> 'getTransportStatus'
				),
				'settransportstatus' => array(
					'title'			=> 'Transportstatus ändern',
					'desc'			=> 'Den Transportstatus eines FaxJobs ändern (z.B. anhalten).',
					'script'		=> $examplesPath.'/job/setTransportStatus.php',
					'help_anchor'	=> 'setTransportStatus'
				)
			)
		);
	}

	public function run() {
		$this->action = isset( $_GET['a'] ) ? strtolower( $_GET['a'] ) : 'intro';

		try {
			$model = $this->getModel();
			$config = $model->getConfiguration();
			$diagnostics = $model->getDiagnostics();
						
			// Wünscht der User die Umgebung zu wechseln, wird diese erzwungen um
			// die Auth-Prüfung auch in der gewünschten Umgebung laufen zu lassen.
			if ( isset($_POST['endpointid'] ) ) {
				$diagnostics->setSelectedEndpointGroupId( $_POST['endpointid'] );
			}
	
			$this->checkQuickStartVersion();
	
			/* =========================== DISPATCHER ========================== */
			do {
				$dispatched = true;
	
				switch ( $this->action ) {
					case 'intro':
						$this->showHeader();
						$this->showIntro();
						$this->showFooter();
	
						break;
					case 'setup':
						if ( ! $diagnostics->isConnectable() || ! $diagnostics->isDefinitionsWritable() ) {
							$this->action = 'diag';
							$dispatched = false;
							break;
						}
	
						$this->showHeader();
						$this->showSetup();
						$this->showFooter();
	
						break;
					case 'applyconfig':
						if ( ! $diagnostics->isConnectable() || ! $diagnostics->isDefinitionsWritable() ) {
							$this->action = 'diag';
							$dispatched = false;
							break;
						}
			
						// Formular validieren
						$form = $this->validateSetupForm();
	
						if ( ! $model->getQsService()->checkAuthentification( $form['authkey'] ) ) {
							header(	'Location: '.$_SERVER['SCRIPT_NAME'].'?a=setup'.
									'&error=auth'.
									'&endpointid='.$form['endpointid'].
									'&authkey='.urlencode( $form['authkey']) );
							exit();
						}
	
						// Config speichern
						try {
							$model->updateDefinitions( $form['authkey'], $form['endpointid'] );
							$model->writeDefinitions();
						}
						catch ( Exception $exception ) {
							header(	'Location: '.$_SERVER['SCRIPT_NAME'].'?a=setup'.
									'&error=savefailed'.
									'&endpointid='.$form['endpointid'].
									'&authkey='.urlencode( $form['authkey']) );
							exit();
						}
						
						header('Location: '.$_SERVER['SCRIPT_NAME'].'?a=diag&configsaved');
	
						break;
					case 'examples':
						$this->showHeader();
	
						if (isset($_GET['cat']) &&
							array_key_exists($_GET['cat'], $this->aExamples) )
						{
							$category = $this->aExamples[ $_GET['cat'] ];
	
							if (isset($_GET['example']) &&
								array_key_exists($_GET['example'], $category['examples']) )
							{
								$example = $category['examples'][ $_GET['example'] ];
								switch ($_GET['example'])
								{
									case 'sendpdf':
									case 'sendhtml':
									case 'sendimage':
										$this->showExample_SendFax($example);
										break;
									case 'sendplaintext':
										$this->showExample_SendFax_PlainText($example);
										break;
									case 'sendpdftolist':
										$this->showExample_SendFax_RecipientList($example);
										break;
	
									case 'getjob':
									case 'getjobprofile':
									case 'getjobcosts':
									case 'getjobmembers':
									case 'gettransportstatus':
										$this->showExample_JobId($example);
										break;
									case 'getjoblist':
									case 'getmembers':
										$this->showExample_GetList($example);
										break;
									case 'settransportstatus':
										$this->showExample_SetTransportStatus($example);
										break;
								}
	
								$this->showExampleSidebar();
							} else {
								// Übersicht der Kategorie
								$this->showExamplesCategoryOverview($_GET['cat'], $category);
							}
						} else {
							// Übersicht Kategorien
							$this->showExamplesOverview();
						}
	
						$this->showFooter();
						break;
					case 'examplesource':
						// Für die Navigation sind wir immer noch bei den Beispielen
						$this->action = 'examples';
	
						if (! isset($_GET['cat']) ||
							! isset($_GET['example']) ||
							! array_key_exists($_GET['cat'], $this->aExamples) ||
							! array_key_exists($_GET['example'], $this->aExamples[$_GET['cat']]['examples']) )
						{
							$dispatched = false;
							break;
						}
	
						$examples = $this->aExamples[$_GET['cat']]['examples'];
	
						$this->showHeader();
						$this->showExampleSource($examples[ $_GET['example'] ]);
						$this->showFooter();
						break;
					case 'exampledownload':
						if (! isset($_GET['cat']) ||
							! isset($_GET['example']) ||
							! array_key_exists($_GET['cat'], $this->aExamples) ||
							! array_key_exists($_GET['example'], $this->aExamples[$_GET['cat']]['examples']) )
						{
							$this->action = 'examples';
							$dispatched = false;
							break;
						}
	
						$examples = $this->aExamples[$_GET['cat']]['examples'];
						$script = $examples[$_GET['example']]['script'];
						if (! file_exists($script))
						{
							die('Datei '.$script.' nicht gefunden. '.
								'Eventuell ist QuickStart nicht komplett installiert.');
						}
	
						header('Content-Type: application/x-httpd-php');
						header('Content-Disposition: attachment; filename="'.basename($script).'"');
	
						readfile($script);
	
						exit();
					case 'support':
						$this->showHeader();
						$this->showSupport();
						$this->showFooter();
						break;
					case 'sendreport':
						header(	'Location: '.$_SERVER['SCRIPT_NAME'].'?a=support'.
								'&report='.( $model->sendReport() ? 'sent' : 'failed' )  );
						break;
					case 'diag':
					default:
						$diagnostics->testPrerequisites();
						$this->showHeader();
						$this->showDiag();
						$this->showFooter();
				}
			} while ( ! $dispatched );
		}
		catch ( MaintenanceException $e ) {
			$this->showHeader(false);
			echo '<div id="waitmessage">'."\n".
				 '<table><tr><td>'."\n".
				 '<img src="images/icn_fatal.gif" alt="achtung" width="48" height="48" />'."\n".
				 '</td><td style="vertical-align: middle;">'."\n".
					// TODO
				 'Derzeit finden Wartungsarbeiten an dem FaxApi-Webdienst statt, wodurch der Einsatz der FaxApi sowie '.
				 'QuickStart derzeit nicht möglich ist.<br/>Bitte versuchen Sie es zu einen späteren Zeitpunkt erneut.<br>'.
				 "\n".'</td></tr></table></div>'."\n";

			$this->showFooter();
			exit();
		}
		catch ( ServiceException $exception ) {
			$this->showHeader(false);
			echo '<div id="waitmessage">'."\n".
				 '<table><tr><td>'."\n".
				 '<img src="images/icn_fatal.gif" alt="achtung" width="48" height="48" />'."\n".
				 '</td><td style="vertical-align: middle;">'."\n".
					// TODO
				 'Derzeit ist der FaxApi-Webdienst nicht erreichbar, wodurch der Einsatz der FaxApi sowie '.
				 'QuickStart derzeit nicht möglich ist.<br/>Bitte versuchen Sie es zu einen späteren Zeitpunkt erneut.<br>'.
				 "\n".'</td></tr></table></div>'."\n";

			$this->showFooter();
			exit();
		}
		
	}

	/**
	 * @return QuickStartApp
	 */
	private function showDiag() {
		$model = $this->getModel();
		$diagnostics = $model->getDiagnostics();
		$definitionsFile = $diagnostics->getDefinitionsFile();
		$definitionsWritable = $diagnostics->isDefinitionsWritable();
		
		echo '<div id="content">';
		
		/* Grundvoraussetzungen */		
		echo '<table><thead><tr><th colspan="3">Grundvoraussetzungen</th></tr></thead><tbody>';
		$test = 'version';
		$title = 'PHP-Version &gt;= ' . PHP_VERSION_MIN;
		if ( ! $diagnostics->isSufficientPhpVersion() ) {
			echo Result::$Fail->fragment( $test, $title, 'zu alt ('.PHP_VERSION.')' );
			$this->aHints[] = 'Aktualisieren Sie (bzw. Ihr Administrator/Hoster) PHP auf mindestens Version 5.0.1';
		} else {
			echo Result::$Ok->fragment( $test, $title, 'vorhanden ('.PHP_VERSION.')');
		}

		$test = 'soap';
		$title = 'SOAP-Unterstützung in PHP';
		if ( ! $diagnostics->isSoapAvailable() ) {
			echo Result::$Fail->fragment( $test, $title, 'nicht vorhanden' );
			$this->aHints[] =	'PHP muss mit der Option <span style="white-space: nowrap;">--enable-soap</span> '.
					  			'konfiguiert sein, um SOAP Unerstützung zu bieten.';
		}
		else {
			echo Result::$Ok->fragment( $test, $title, 'vorhanden' );
		}
		echo '</tbody></table><br/>';		

		/* Versandsysteme */
		echo '<table><thead><tr><th colspan="3">Versandsysteme</th></tr></thead><tbody>';
		foreach( $diagnostics->getEndpointGroupIds() as $endpointGroupId ) {
			$endpointGroup = $diagnostics->getEndpointGroup( $endpointGroupId );
			$test = 'host.'.$endpointGroupId;
			$title = $this->endpointHostNames[$endpointGroupId];
			if ( ! $diagnostics->isSoapAvailable() ) {
				$fragment =  Result::$NA->fragment( $test, $title, 'kein Soap' . ( $endpointGroup->isConnectableIp() ? ' (IP-Verbindung)' : '' ) );
			}
			else if ( $endpointGroup->isConnectable() ) {
				$fragment = Result::$Ok->fragment( $test, $title, 'ok' );
			}
			else if ( $endpointGroup->isConnectableIp() ) {
				$fragment = Result::$Warn->fragment( $test, $title, 'nur IP-Verbindung' );
			}
			else  {
				$fragment =  Result::$Fail->fragment( $test, $title, 'Fehler' );
				$this->aHints[] = $title . ' nicht erreichbar.';
			}
			echo $fragment;
		}
		echo '</tbody></table><br/>';		
		
		/* Konfiguration */
		echo '<table><thead><tr><th colspan="3">Konfiguration</th></tr></thead><tbody>';
		$test = 'writeaccess';
		$title =  'Schreibrechte (' . basename( $definitionsFile ) . ')';
		if ( $definitionsWritable ) {
			echo Result::$Ok->fragment( $test, $title,  'vorhanden');
		}
		else {
			echo Result::$Warn->fragment( $test, $title, 'nicht vorhanden');
		}
		$test = 'setup';
		$title = 'Einstellungen';
		if ( $model->isConfigured() ) {
			echo Result::$Ok->fragment( $test, $title, 'definiert' );
		}
		else {
			echo Result::$Warn->fragment( $test, $title, 'offen' );
		}
		echo '</tbody></table><br/>';
		echo  '<div id="checkdate" class="right">Prüfungszeitpunkt: '. date( 'H:i:s', $diagnostics->getTestTime() ) . ' Uhr&nbsp;&nbsp;&nbsp;</div>';
		echo '</div> <!-- content end -->';
		
		echo '<div id="sidebar">';

		if ( isset($_GET['configsaved']) ) {
			echo '<div class="box rounded" style="border-color: green;">'."\n".
				 '<div class="boxtitle"><img src="images/icn_ok.gif" alt="ok" /> Konfiguration gespeichert</div>'."\n".
				 '</div>'."\n";
		}


		// Statustext zusammensetzen

		// Block 1: API nutzbar/teilweise/unnutzbar

		if ( $diagnostics->isFullyConnectable() ) {
			$status = '<p>Dieser Webserver erfüllt alle Anforderungen zur Nutzung der Fax-API!</p>';
			$borderColor = 'green';
		} else if ( $diagnostics->isConnectable() ) {
			$status = '<p>Dieser Webserver erlaubt eine eingeschränkte Nutzung der Fax-API!</p>';
			$borderColor = 'orange';
		} else {
			$status = '<p>Dieser Webserver erfüllt nicht die Anforderungen zur Nutzung der Fax-API.</p>';
			$borderColor = 'red';
		}

		// Block 2: Konfigurationsstatus und Ergebnis der Zugriffsrechte-Test(s) berücksichtigen
		if ( $diagnostics->isConnectable() ) {
			if ( ! $model->isConfigured() ) {
				$status.= '<p>Wenn Sie die Beispiele ausprobieren möchten, müssen Sie Ihre API-Zugangsdaten konfigurieren.</p>';
				if ( ! $definitionsWritable ) {
					$status.=	'<p>Das ist jedoch aufgrund fehlender Schreibrechte zurzeit nicht möglich!</p>';
					if ($borderColor != 'red') {
						$borderColor = 'orange';
					}
				}
			}
			else {
				$status .= '<p>Sie könnten jetzt die Beispiele zur Nutzung der Fax-API jetzt ausprobieren.</p>';
			}
		}

		// "Prüfergebnis" ausgeben
		echo '<div class="box rounded" style="border-color: '.$borderColor.';">'."\n".
			 '<div class="boxtitle">Prüfergebnis</div>'.$status;

		if ( ! empty($this->aHints) ) {
			echo '<ul>'."\n";
			foreach ( $this->aHints as $hint ) {
				echo '<li>'.$hint.'</li>'."\n";
			}
			echo '</ul>'."\n".
				 '<p>Informieren Sie Ihren Administrator/Hoster über '.
				 (count($this->aHints) > 1 ? 'diese Probleme' : 'dieses Problem'). ', '.
				 'und führen zur weiteren Diagnose die Prüfungen erneut durch.</p>'."\n";
		}

		// Irgend ein kleinstes Problem ? "Erneut prüfen" anbieten
		if ( ! $diagnostics->isConnectable() || ! $definitionsWritable ) {
			echo '<p><a id="diag" href="'.$_SERVER['SCRIPT_NAME'].'?a=diag&amp;ts='.time().'"><img src="images/icn_reload.gif" alt="" />&nbsp;Erneut prüfen</a>';
		}

		// "Nächstet Schritt"

		// API/Rechte OK + nicht konfiguiert -> Konfiguration
		if ( ! $diagnostics->isFullyConnectable() && $definitionsWritable && ! $model->isConfigured() ) {
			echo '<p><a id="setup" href="?a=setup"><img src="images/icn_setup.gif" alt="" />&nbsp;API Konfiguration erstellen</a></p>';
		}

		// API OK + konfiguiert -> Beispiele
		if ( ! $diagnostics->isFullyConnectable() && $model->isConfigured() ) {
			echo '<p><a id="examples" href="?a=examples"><img src="images/icn_examples.gif" alt="" />&nbsp;Zu den Beispielen</a></p>';
		}
		echo '</div>';
	
		echo '</div> <!-- sidebar end -->';
	}
	
	// === KONFIGURATION

	/**
	 * @return QuickStartApp
	 */
	private function showSetup() {
		$model = $this->getModel();
		$definitions = $model->getDefinitions();
		$diagnostics = $model->getDiagnostics();
		
		$currentEndpointId = isset($_GET['endpointid']) ? $_GET['endpointid'] : $diagnostics->getSelectedEndpointGroupId();
		$authkey = isset($_GET['authkey']) ? $_GET['authkey'] : ( array_key_exists( 'FAX_AUTHKEY', $definitions ) ? $definitions['FAX_AUTHKEY'] : '' );

		echo '<div id="content">';
		
		echo '<h3>Konfigurationsparameter</h3>';
		echo '<p>Die Konfigurationsparameter werden zur Ausführung der Beispiele benötigt.</p>';

		echo '<form method="post" action="'.$_SERVER['SCRIPT_NAME'].'?a=applyConfig">'."\n";
		if ( isset($_GET['error'] ) ) {
			switch ($_GET['error']) {
				case 'auth':
					$msg = '<p>Der angegebenen AuthKey ist nicht korrekt - bitte prüfen Sie ihn und versuchen es erneut.</p>';
					break;
				case 'emptyauth':
					$msg = '<p>Bitte geben Sie Ihren AuthKey in das entsprechende Feld ein.</p>';
					break;
				case 'savefailed':
					$msg = '<p>Die Konfiguration konnte aus unersichtlichen Gründen nicht gespeichert werden.</p>'.
						   '<p>Versuchen Sie erneut zu speichern, sollte dieser Fehler erneut auftauchen '.
					       'und sich nicht beheben lassen, hilft Ihnen unserer Support gerne weiter.</p>';
					break;
				default:
					$msg =	'<p>Beim Speichern Ihrer Konfiguration lief etwas unerwartet schief!</p>'.
							'<p>Versuchen Sie erneut zu speichern, sollte dieser Fehler jedoch erneut auftreten '.
					        'und sich nicht beheben lassen, hilft Ihnen unserer Support gerne weiter.</p>';
			}

			echo '<div id="error" class="box rounded" style="border-color: red;">'.
				 '<div class="boxtitle">Fehler</div>'. $msg.'</div>';
		}
echo <<<EOD
	<table>
		<tr>
			<td><label for="endpointid">Versandsystem</label>&nbsp;</td>
			<td><select id="endpointid" name="endpointid">
EOD;
		foreach( $diagnostics->getEndpointGroupIds() as $endpointGroupId ) {
			$endpointGroup = $diagnostics->getEndpointGroup( $endpointGroupId );
			echo '<option value="' . $endpointGroupId . '"';
			if ( ! $endpointGroup->isConnectable() ) {
				echo ' disabled="disabled"';
			} else if ( $currentEndpointId == $endpointGroupId ) {
				echo ' selected="selected"'; 
			}
			echo '>';
			echo $this->endpointHostNames[$endpointGroupId];
			echo '</option>'."\n";
		}
echo <<<EOD
					</select></td>
				</tr>
				<tr>
				 	<td><label for="authkey">AuthKey</label>&nbsp;</td>
				 	<td><input id="authkey" type="text" name="authkey" value="$authkey" />
				</tr>
			</table>
			<button type="submit">Speichern</button>
		</form>
	</div>

	<div id="sidebar">
		<div class="box rounded">
			<div class="boxtitle">Konfiguration</div>
				Bitte füllen Sie das Formular mit folgenden Informationen aus:<br/>
			<ul>
				<li><b>AuthKey</b><br/>
					Ihr API Zugangsschlüssel. Sollten Sie noch keinen haben, können Sie dies
					<a id="account" href="http://www.fax-api.de/testzugang/" target="_blank">hier</a> nachholen.
				</li>
				<li><strong>Versandsystem</strong><br/>
			 		Wählen Sie das Versandsystem über das die Beispiele gesendet werden sollen.
			 </ul>

			<p>Der AuthKey muss für das gewählte Versandsystem gültig sein.</p>
			<script type="text/javascript">document.getElementById("authkey").focus();</script>
		</div>
	</div>
EOD;
	}


	/**
	 * @return array
	 */
	private function validateSetupForm() {
		$quickstart = $this->getModel();
		$diagnostics = $quickstart->getDiagnostics();

		$ret = array();
		$endpointId = isset($_POST['endpointid']) ? trim( $_POST['endpointid'] ) : null;
		$authkey = isset( $_POST['authkey'] ) ? trim( $_POST['authkey'] ) : null;
		
		if ( empty( $authkey ) ) {
			header('Location: '.$_SERVER['SCRIPT_NAME'].'?a=setup&error=emptyauth&endpointid='.$endpointId);
			exit();
		}
		
		if ( empty( $endpointId ) || ! in_array( $endpointId, $diagnostics->getEndpointGroupIds() ) ) {
			header('Location: '.$_SERVER['SCRIPT_NAME'].'?a=setup&error=invalidendpoint' );
			exit();
		}
		
		return array( 'endpointid' => $endpointId, 'authkey' => $authkey );
	}

	// === BEISPIELE

	private function showExamplesOverview() {
		$model = $this->getModel();
		
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">Beispiele Übersicht</div>
			<p>Bitte wählen Sie eine Kategorie:</p>
			<ul>
EOD;

		foreach ( $this->aExamples as $name => $category ) {
			echo
<<<EOD
				<li><a id="examples.{$name}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$name}">{$category['desc']}</a></li>
EOD;
		}

		// Hilfetext an der Seite
		echo
<<<EOD
			</ul>
		</div>
	<div id="sidebar">
EOD;
		if ( ! $model->isConfigured() ) {
			echo
<<<EOD
				<div class="box rounded" style="border-color: orange;">
					<div class="boxtitle">Hinweis</div>
					<p>Um die hier gezeigten Beispiele ausprobieren zu können, müssen Sie zuerst unter "Konfiguration"
					die dort gezeigte Einstellungen vornehmen.</p>
				</div>
EOD;
		}
		echo
<<<EOD
		<div class="box rounded">
			<div class="boxtitle">Beispiele</div>
				<p>Hinter diesen Kategorien finden Sie einige Beispiele zur Nutzung der Fax-API, welche
				Sie sofort ausprobieren, oder als Grundlage Ihrer eigenen Integration nutzen können.</p>
				<p>Alle hier aufgelisteten Beispiele finden Sie im Ordner</p>
				<p><em>examples</em></p>
				<p>innerhalb des QuickStart Ordners</p>
			</div>
		</div>
EOD;
	}

	/**
	 * @param array $category
	 */
	private function showExamplesCategoryOverview( $catName, &$category ) {
		/* Workaround to use constans in heredocs */
		$resolve = create_function( '$const', 'return $const;' );
		
		$model = $this->getModel();
		echo
<<<EOD
		<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; {$category['desc']}
		</div>
	<div class="scrollpane"><div style="position: relative;">
EOD;
		foreach ($category['examples'] as $exampleName => $example) {
			$actionName = key($example); 
			echo
<<<EOD
			<table class="exampleinfo"><tr>
				<td class="exampletitle"><h4>{$example['title']}</h4>{$example['desc']}</td>
				<td style="vertical-align: middle;">
EOD;
			if ( $model->isConfigured() ) { 
				echo
<<<EOD
				<a id="examples.{$catName}.{$exampleName}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$catName}&example={$exampleName}">
				<img src="images/icn_run.gif" alt="" />&nbsp;Beispiel ausführen</a><br/>
EOD;
			}
			echo
<<<EOD
			<a id="examplesource.{$catName}.{$exampleName}" href="{$_SERVER['SCRIPT_NAME']}?a=examplesource&cat={$catName}&example={$exampleName}">
			<img src="images/icn_view.gif" alt="" />&nbsp;Quelltext anzeigen</a></td>
			</tr></table>
EOD;
		}
		// Hilfetext
		echo '</div></div></div><div id="sidebar">';
		if ( ! $model->isConfigured() ) {
			echo
<<<EOD
			<div class="box rounded" style="border-color: orange;">
				<div class="boxtitle">Hinweis</div>
				<p>Um die hier gezeigten Beispiele ausprobieren zu können, müssen Sie zuerst unter "Konfiguration"
				die dort gezeigte Einstellungen vornehmen.</p>
			</div>
EOD;
		}
		echo
<<<EOD
		<div class="box rounded">
			<div class="boxtitle">Beispiele</div>
			<p>Sie können von hier aus jedes Beispiel entweder sofort ausprobieren,	oder direkt zur Quelltext-Ansicht springen.</p>
			<p>Die Beispiele finden Sie im Ordner <em>examples/{$catName}</em> innerhalb des QuickStart-Ordners</p>
		</div>
	</div>
EOD;
	}

	/**
	 * @return string
	 */
	private function getCurrentCategoryDesc() {
		if ( ! isset( $_GET['cat'] ) ) {
			return;
		}
		return $this->aExamples[$_GET['cat']]['desc'];
	}

	/**
	 * @param array $example
	 */
	private function showExample_JobId( $example ) {
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			 &gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			 &gt; {$example['title']}
		</div>
		<h3>{$example['title']}</h3>
		<p>Dieses Beispiel benötigt die Eingabe einer Job-Id, welche jeden gestarteten Faxauftrag eindeutig identifiziert.</p>
		<p>Wenn Sie auf die schnelle eine Job-Id für die Beispiele erhalten möchten, starten Sie ein Beispiel aus der
		   Kategorie "Faxe versenden", und geben die zurück gegebende Job-Id hier ein.</p>

		<form action="{$example['script']}" method="GET" target="exampleframe">
			 <table>
			 	<tr>
			 		<td><label for="jobid">Job-Id: </label></td>
			 		<td><input type="text" id="jobid" name="jobid" />&nbsp;<button type="submit">Start</button></td>
			 	</tr>
			 </table>
		</form>
		<br/>
		<script type="text/javascript">document.getElementById("jobid").focus();</script>

		<!-- Ausgabe IFrame -->
		<span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		<iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	</div>
EOD;
	}

	/**
	 * @param array $example
	 */
	private function showExample_GetList($example) {
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
	 	</div>
        <h3>{$example['title']}</h3>
		{$example['desc2']}<br/>Alle Felder sind optional.<br/><br/>
	 	<form action="{$example['script']}" method="GET" target="exampleframe">
		 	<table class="exampleform">
			 	<tr>
			 		<td><label for="title">Titel: </label></td>
			 		<td><input type="text" id="title" name="title" /></td>
			 	</tr>
			 	<tr>
					<td><label for="status">Status: </label></td>
					<td><select id="status" name="status" />
						<option value="">--- alle ---</option>
						<option>new</option>
						<option>scheduled</option>
						<option>finished</option>
						<option>error</option>
					</select></td>
				</tr>
				<tr><td></td><td><button type="submit">starten</button></td></tr>
	 		</table>
	 	</form><br/>
		 <span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		 <iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	 </div>
	 <script type="text/javascript">document.getElementById("title").focus();</script>
EOD;
	}


	/**
	 * @param array $example
	 */
	private function showExample_SetTransportStatus( $example ) {
		echo 
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
	 	</div>
     	<h3>{$example['title']}</h3>
	 	<form action="{$example['script']}" method="GET" target="exampleframe">
		 	<table class="exampleform">
			 	<tr>
			 		<td><label for="jobid">jobId: </label></td>
			 		<td><input type="text" id="jobid" name="jobid" /></td>
			 	</tr>
			 	<tr>
					<td><label for="status">Status: </label></td>
					<td><select id="status" name="status" />
						<option>enabled</option>
						<option>halted</option>
						<option>canceled</option>
					</select></td>
				</tr>
				<tr>
			 		<td></td>
			 		<td><button type="submit">starten</button></td>
			 	</tr>
		 	</table>
		 </form>
		 <br/>
		 <span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		 <iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	</div>
	<script type="text/javascript">document.getElementById("title").focus();</script>
EOD;
	}


	/**
	 * @param array $example
	 */
	private function showExample_SendFax( $example ) {
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
		</div>
		<h3>{$example['title']}</h3>
		<!-- Formular -->
		<form action="{$example['script']}" method="GET" target="exampleframe">
			<table>
			 	<tr>
			 		<td><label for="title">Titel: </label></td>
			 		<td><input type="text" id="title" name="title" value="{$example['documentTitle']}"/></td>
			 	</tr>
				<tr>
					<td><label for="recipient">Zielfaxnummer: </label></td>
					<td><input type="text" id="recipient" name="recipient" value="" />&nbsp;
						<button type="submit">start</button></td>
				</tr>
			</table>
		</form>
		<br/>
		<script type="text/javascript">document.getElementById("recipient").focus();</script>

		<!-- Ausgabe IFrame -->
		<span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		<iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	</div>
EOD;
	}

	/**
	 * @param array $example
	 */
	private function showExample_SendFax_PlainText($example) {
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
		</div>
		<h3>{$example['title']}</h3>
		<p>In diesem Beispiel wird neben der Zielfaxnummer auch der Fax-Inhalt als Klartext übergeben.</p>

		<!-- Formular -->
		<form action="{$example['script']}" method="GET" target="exampleframe">
			<table>
			 	<tr>
			 		<td><label for="title">Titel: </label></td>
			 		<td><input type="text" id="title" name="title" value="{$example['documentTitle']}"/></td>
			 	</tr>
				<tr>
			 		<td><label for="recipient">Zielfaxnummer: </label></td>
			 		<td><input type="text" id="recipient" name="recipient" value="" /></td>
			 	</tr>
			 	<tr>
					<td><label for="faxcontent">Inhalt: </label></td>
			 		<td><textarea id="faxcontent" name="content">Hier steht der Inhalt Ihres Faxes</textarea></td>
			 	</tr>
			 	<tr>
			 		<td></td>
			 		<td><button type="submit">start</button></td>
			 	</tr>
			 </table>
		</form>
		<br/>
		<script type="text/javascript">document.getElementById("recipient").focus();</script>

		<!-- Ausgabe IFrame -->
		<span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		<iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	</div>
EOD;
	}


	/**
	 * @param array $example
	 */
	private function showExample_SendFax_RecipientList($example) {
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
		</div>
		<h3>{$example['title']}</h3>
		<p>In diesem Beispiel wird neben der Zielfaxnummer auch der Fax-Inhalt als Klartext übergeben.</p>

		<!-- Formular -->
		<form action="{$example['script']}" method="GET" target="exampleframe">
			<table>
			 	<tr>
			 		<td><label for="title">Titel: </label></td>
			 		<td><input type="text" id="title" name="title" value="{$example['documentTitle']}"/></td>
			 	</tr>
				<tr>
					<td><label for="recipients">Empfänger: </label></td>
			 		<td>
			 			<textarea id="recipients" name="recipients"></textarea><br/>
			 			<small>(pro Zeile eine Faxnummer)</small>
			 		</td>
			 	</tr>
			 	<tr>
					<td></td>
					<td><button type="submit">start</button></td>
			 	</tr>
			 </table>
		</form>
		<br/>
		<script type="text/javascript">document.getElementById("recipients").focus();</script>

		<!-- Ausgabe IFrame -->
		<span class="exampleframelabel">Beispiel-Ausgabe:</span><br/>
		<iframe name="exampleframe" class="exampleframe" frameborder="0"></iframe>
	</div>
EOD;
	}




	/**
	 * @param array $example
	 * @return QuickStartApp
	 */
	private function showExampleSource( &$example ) {
		$model = $this->getModel();
		$hlp_class = $this->aExamples[$_GET['cat']]['help_class'];
		$hlp_anchor = $example['help_anchor'];
		$scriptFile = $example['script'];
		
		echo
<<<EOD
	<div id="content">
		<div class="surfnav">
			<a id="examples" href="{$_SERVER['SCRIPT_NAME']}?a=examples">Beispiele Übersicht</a>
			&gt; <a id="examples.{$_GET['cat']}" href="{$_SERVER['SCRIPT_NAME']}?a=examples&cat={$_GET['cat']}">{$this->getCurrentCategoryDesc()}</a>
			&gt; {$example['title']}
		</div>
EOD;

		if ( ! file_exists($scriptFile) ) {
			echo 'Datei '.realpath( $scriptFile ).' nicht gefunden !<br/>Eventuell ist QuickStart nicht vollständig installiert.<br/>';
		}
		else {
			echo '<div id="examplesource">' . highlight_file( $scriptFile, true ) . '</div>';
		}

		echo '</div> <!-- content end -->'."\n".
			 '<div id="sidebar">'."\n";

		if (! $model->isConfigured() ) {
			echo
<<<EOD
		<div class="box rounded" style="border-color: orange;">
			<div class="boxtitle">Hinweis</div>
			<p>Um das hier gezeigten Beispiel ausprobieren zu können, müssen Sie zuerst unter "Konfiguration"
			die dort gezeigte Einstellungen vornehmen.</p>
		</div>
EOD;
		}

		$scriptName = basename( $scriptFile );
		$scriptFolder = strstr( dirname( $scriptFile ), '/' );
		echo
<<<EOD
	<div class="box rounded">
		<div class="boxtitle">Beispiel Quelltext</div>
		<p>Script: <br/><em>{$scriptName}</em></p>
		<p>Ordner: <br/><em>{$scriptFolder}</em></p>
		<p>Die zum ausführen der Beispiele benötigten Dateien finden Sie unter:</p>
		<p><em>/classes/</em></p>
	</div>
	<div class="box rounded">
		<div class="boxtitle">Aktionen</div>
EOD;
		if ( $model->isConfigured() ) {
			$url = $_SERVER['SCRIPT_NAME'].'?a=examples&amp;cat='.$_GET['cat'].'&amp;example='.$_GET['example'];
			echo 
<<<EOD
			<p><a id="examples.{$_GET['cat']}.{$_GET['example']}" href="{$url}"><img src="images/icn_run.gif" alt=""/>&nbsp;Beispiel ausführen</a></p>
EOD;
		}
		
		$url = $_SERVER['SCRIPT_NAME'] . '?a=exampledownload&amp;cat='. $_GET['cat'] . '&amp;example='. $_GET['example'];
		echo 
<<<EOD
			<p><a id="exampledownload.{$_GET['cat']}.{$_GET['example']}" href="{$url}"><img src="images/icn_download.gif" alt=""/>&nbsp;Quelltext downloaden</a></p>
EOD;
		$url = dirname( $_SERVER['SCRIPT_NAME'] ).'/../doc/api/index.html'.$hlp_class.'.html#'.$hlp_anchor;
		echo
<<<EOD
			<p><a id="apidoc" href="{$url}" target="blank"><img src="images/icn_view.gif" alt=""/>&nbsp;API Dokumentation</a></p>
		</div>
	</div> <!-- sidebar end -->
EOD;
	}


	private function showExampleSidebar() {
		// Seitenleiste
		echo
<<<EOD
	<div id="sidebar">
		<div class="box rounded">
			<div class="boxtitle">Aktionen</div>
			<p><a id="examplesource.{$_GET['cat']}.{$_GET['example']}" href="{$_SERVER['SCRIPT_NAME']}?a=examplesource&amp;cat={$_GET['cat']}&amp;example={$_GET['example']}">
		 	   <img src="images/icn_view.gif" alt=""/>&nbsp;Quelltext anzeigen</a></p>
		 	<p><a id="exampledownload.{$_GET['cat']}.{$_GET['example']}" href="{$_SERVER['SCRIPT_NAME']}?a=exampledownload&amp;cat={$_GET['cat']}&amp;example={$_GET['example']}">
		 	   <img src="images/icn_download.gif" alt=""/>&nbsp;Quelltext downloaden</a></p>
		 </div>
	</div> <!-- sidebar end -->
EOD;
	}


	private function showIntro() {
		echo
 <<<EOD
	<div id="content">
		<h3>Einführung</h3>
		<p>Der Fax-API QuickStart besteht aus folgenden Bausteinen:
			<ul>
				<li><h4>Diagnose-Tool</h4>
					<p>Das Diagnose-Tool prüft Ihren Webserver auf die geforderten Systemanforderungen der Fax-API.
					Prüfgegenstand sind hierbei PHP-Version, SOAP-Unterstützung und Konnektierbarkeit zu den Versandsystemen.</p> 
				</li>
				<li><h4>PHP-Sourcecode</h4> 
					<p>Die Beispiele demonstrieren verschiedene Einsatzszenarien um die Fax-API in PHP-Anwendungen zu integrieren.
					Der kommentierte Sourcecode und die einfachen Beispiele erlauben Ihnen einen schnellen Zugang zur Nutzung
					der Fax-API innerhalb einer PHP-Anwendung.</p>
					<h4>Hinweis</h4>
					<p>Mit einem AuthKey können Sie die Beispiele auch direkt ausführen und sich Testfaxe zuschicken lassen.
					Informationen zum Erhalt eines AuthKeys erhalten Sie <a id="account" href="http://www.fax-api.de/testzugang/" target="_blank">hier</a>.</p>
				</li>
				<li><h4>Dokumentation der Client-Library</h4></li>
			</ul>
		</p>
	</div>
	<div id="sidebar">
		<div class="box rounded"><div class="boxtitle">Benötigen Sie Hilfe?</div>
			<p>Wenn Sie Fragen oder Anregungen bezüglich QuickStart oder der Fax-API haben sollten, helfen wir Ihnen gerne weiter.</p>
			<p><a id="support" href="mailto:support@fax-api.de"><img src="images/icn_mail.gif" alt="" />&nbsp;Support</a></p></div>
	</div>
EOD;
	}
	
	/*
		=== SUPPORT ===
	*/


	/**
	 * @return QuickStartApp
	 */
	private function showSupport() {
		$model = $this->getModel();
		$docPath = dirname( $_SERVER['SCRIPT_NAME'] ) . '/../doc/api/index.html';
		echo 
<<<EOD
	<div id="content">
		<h3>Hilfe und Support</h3>
		<p>Hier einige Links welche Sie bei der Arbeit mit der Fax-API unterstützen können.</p>
		<ul>
			<li><a id="faxapi" href="http://www.fax-api.de/">Fax-API Website</a></li>
		 	<li><a id="apidoc" href="{$docPath}" target="_blank">PHP Client Library Dokumentation</a></li>
		</ul>
		<h3>Bericht</h3>
		<ul>
			<li><a a="report.show" href="#" onClick="toggleVisibility( document.getElementById('report') );"><strong>Testbericht einsehen</strong></a>
			    <div id="report" class="codebox">{$model->report()}</div>
			</li>
			<li>
EOD;
		// "Testbericht an Teamnet senden"
		if ( isset($_GET['report']) && $_GET['report'] === 'sent') {
			echo '<strong style="color: green;">Testbericht wurde versendet</strong>';
		}
		else if ( isset($_GET['report']) && $_GET['report'] === 'failed') {
			echo '<strong style="color: red;">Testbericht konnte nicht gesendet werden</strong>';
		}
		else {
			echo '<a id="report.send" href="'.$_SERVER['SCRIPT_NAME'].'?a=sendreport">Testbericht an Teamnet senden</a>';
		}
		echo
<<<EOD
			</li>
		</ul>
	</div>
	<div id="sidebar">
EOD;
		$model = $this->getModel();
		$qsVersionInfo = $model->getQsVersionInfo();
		if (  $qsVersionInfo->versionStatus == 'deprecated' ) {
			echo
<<<EOD
		<div class="box rounded" style="border-color: orange;">
			<div class="boxtitle">Neue Version verfügbar</div>
			<p>Wenn Sie ein Problem haben sollten, aktualisieren Sie QuickStart bitte auf die aktuelle Version, bevor
			  Sie unseren Support kontaktieren.</p>
			<p><a id="update.download" href="{$qsVersionInfo->versionDownloadLink}" target="_blank"><img src="images/icn_download.gif" alt=""/>&nbsp;Download</a></p>
		 	<p><a id="update.info" href="{$qsVersionInfo->versionInfoLink}" target="_blank"><img src="images/icn_info.gif" alt=""/>&nbsp;Informationen</a></p>
		</div>
EOD;
		}
		echo
<<<EOD
		<div class="box rounded"><div class="boxtitle">Benötigen Sie Hilfe ?</div>
		<p>Wenn Sie Fragen oder Anregungen bezüglich QuickStart oder der Fax-API haben sollten, helfen wir Ihnen gerne weiter.</p>
		<p><a id="support" href="mailto:support@fax-api.de"><img src="images/icn_mail.gif" alt="" />&nbsp;Support</a></p></div>
	</div>
EOD;
		
	}

	private function checkQuickStartVersion() {
		$model = $this->getModel();
		$diagnostics = $model->getDiagnostics();
		$qsVersionInfo = $model->getQsVersionInfo();
		
		if ( $qsVersionInfo->versionStatus == 'inactive' ) {
			$this->showHeader(false);
			echo
<<<EOD
			<div id="waitmessage">
				 <table>
				 	<tr>
				 		<td><img src="images/icn_fatal.gif" alt="Achtung"/></td>
				 		<td style="vertical-align: middle;">
							Die von Ihnen verwendete Version von QuickStart ist veraltet, und sollte nicht länger
						 	verwendet werden !<br/>Bitte laden Sie sich die aktuelle Version (v{$qsVersionInfo->actualVersion})
						 	herunter und installieren diese.
						 </td>
					</tr>
				</table>
				<div style="margin: 10px 70px;">
				<p><a id="update.download" href="{$qsVersionInfo->versionDownloadLink}"><img src="images/icn_download.gif" alt="download"/>&nbsp;QuickStart&nbsp;v{$qsVersionInfo->actualVersion} downloaden</a></p>
				<p><a id="update.info" href="'.$qsVersionInfo->versionInfoLink.'" target="_blank"><img src="images/icn_info.gif" alt="info"/>&nbsp;Informationen zur neuen Version</a></p>
				</div></div>
EOD;
			$this->showFooter();
			exit();
		}
		else {// $upd->versionStatus == 'deprecated'
			// Update ignorieren ?
			if ( isset( $_GET['ignoreupdate'] ) && $diagnostics->isConfigurationWritable()  ) {
				$model->postponeUpdate();
				header('Location: '.$_SERVER['SCRIPT_NAME'].'?a='.$_GET['a']);
				exit();
			}
		}
	}


	/**
	 * @param bool $showNav
	 * @return QuickStartApp
	 */
	private function showHeader( $showNav = true ) {
		$model = $this->getModel();
		$config = &$model->getConfiguration();
		echo
<<<EOD
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="de" lang="de">
	<head>
		<title>Fax-API QuickStart</title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<meta http-equiv="content-language" content="de" />
		<meta name="copyright" content="Teamnet GmbH" />
		<link href="css/quickstart.css" rel="stylesheet" type="text/css" />
		<!--[if IE 6]>
	    	<style type="text/css">@import url(css/ie6.css);</style>
		<![endif]-->
		<!--[if IE 7]>
	    	<style type="text/css">@import url(css/ie7.css);</style>
		<![endif]-->
		<script type="text/javascript" src="quickstart.js"></script>
	</head>
<body>
<div id="main" class="rounded">
	<div id="appname">
		<h1>Fax-API QuickStart</h1>
		<p id="releaseinfo">v{$config['Quickstart']['Version']}</p>
	</div>
EOD;
		if ( $showNav ) {
			echo '<div id="nav"><ul>';
			$diagnostics = $model->getDiagnostics();
			$this->printNavItem('Einführung', 'Einführung in das QuickStart-Programm',
								'intro', 'intro', $this->action == 'intro');
			$this->printNavItem('Diagnose', 'Ihren Server auf Fax-API Kompatibilität prüfen',
								'diag', 'diag', $this->action == 'diag');
			$this->printNavItem('Konfiguration', 'Konfiguration bearbeiten',
								'setup', 'setup', $this->action == 'setup',
								 $diagnostics->isConnectable() && $diagnostics->isDefinitionsWritable() );
			$this->printNavItem('Beispiele', 'Beispiele zur Nutzung der Fax-API',
								'examples', 'examples', $this->action == 'examples');
			$this->printNavItem('Support', 'Hilfe und Support',
								'support', 'support', $this->action == 'support');
			echo '</ul></div>';
			echo '<div style="clear: both;"></div>';
			if ( $model->isUpdateAvailable() ) {
				$qsVersionInfo = $model->getQsVersionInfo();
				echo
<<<EOD
	<div id="updatenotify" class="rounded">
		Eine neue Version von QuickStart ist verfügbar: v{$qsVersionInfo->actualVersion} &nbsp;&nbsp;&nbsp;
		<a id="update.download" href="{$qsVersionInfo->versionDownloadLink}" target="_blank"><img src="images/icn_download.gif" alt=""/>&nbsp;Download</a>
		<a id="update.info" href="{$qsVersionInfo->versionInfoLink}" target="_blank"><img src="images/icn_info.gif" alt=""/>&nbsp;Informationen</a>
EOD;
				// ignorieren anbieten, wenn config schreibbar
				if ( $diagnostics->isConfigurationWritable() ) {
					echo '<a id="update.ignore" href="'.$_SERVER['SCRIPT_NAME'].'?a='.$_GET['a'].'&ignoreupdate" title="Dieses Update ignorieren">'.
				 		 '<img src="images/icn_fail.gif" alt="" /> Ignorieren</a>';
				}
				echo '</div>';
			}
		}
		echo '<div id="navseperator"></div>';
	}


	/**
	 * @param string $name
	 * @param string $iconName
	 * @param string $this->actionName
	 * @param bool $active
	 * @param bool $enabled
	 */
	private function printNavItem($name, $tooltip, $iconName, $actionName, $active, $enabled = true)
	{
		$icnSuffix = '';

		if (! $enabled) {
			$link = '<li class="disabled" title="'.$tooltip.'">';
			$icnSuffix = '_disabled';
		}
		else {
			$link = '<li'.($active ? ' class="active"' : '').
					'><a id="menu.'.$actionName.'" title="'.$tooltip.'" href="'.$_SERVER['SCRIPT_NAME'].
					'?a='.$actionName.'">';
		}

		$link.= '<img src="images/nav_'.$iconName.$icnSuffix.'.gif" alt="icon" />'.$name;

		if ($enabled) {
			$link.= '</a>';
		}
		
		$link.= '</li>'."\n";

		echo "\t\t\t".$link;
	}


	/**
	 * @return QuickStartApp
	 */
	private function showFooter() {
		echo
<<<EOD
			<div style="clear: both;"></div>
			<div id="footer">
				<table border="0" cellpadding="0" cellspacing="0">
					<tr>
						<td><p>Teamnet GmbH</p></td>
						<td><p>Technologiepark 20<br/>33100 Paderborn</p></td>
						<td><p>Telefon: 0 52 51 / 87 92 93 - 15<br/>Telefax: 0 52 51 / 87 92 93 - 99</p></td>
						<td class="right">
							<p>E-Mail: <a id="footer.support" href="mailto:support@fax-api.de">support@fax-api.de</a><br/>
							   Webseite: <a id="footer.faxapi" href="http://www.fax-api.de" target="_blank">www.fax-api.de</a></p>
						</td>
					</tr>
				</table>
			</div>
		</div>
	</body>
	</html>
EOD;
	}

}
